Capped Nanotubes

## 2.3 Capped Nanotubes

The options to define the input parameters for the construction of the capped nanotube are displayed in the Calculations–Input as shown in Fig 4:

Figure 4: `NanoCap` input options for a capped nanotube

The following input options can be set for the capped nanotube construction.

- the chirality ()

- the length of the nanotube ()

- the number of cap carbon atoms and dual lattice points (or enabled the estimation based upon the nanotube density)

- the seed for the initial random cap point placement

- the force cutoff relating to the dual lattice force field (Section 4.1)